==> tswlib-1.0.0.tgz: package/elm.js <==
import { EventKind } from "./types";
export var privates;
(function (privates) {
    let ElementGeneric;
    (function (ElementGeneric) {
        ElementGeneric.tagName = Symbol('ElementGeneric_tagName');
        ElementGeneric.ns = Symbol('ElementGeneric_ns');
        ElementGeneric.children = Symbol('ElementGeneric_children');
        ElementGeneric.addHandler = Symbol('ElementGeneric_addHandler');
        ElementGeneric.attrs = Symbol('ElementGeneric_attrs');
        ElementGeneric.events = Symbol('ElementGeneric_events');
        ElementGeneric.getRefs = Symbol('ElementGeneric_getRefs');
    })(ElementGeneric = privates.ElementGeneric || (privates.ElementGeneric = {}));
    let ElementWithValueBase;
    (function (ElementWithValueBase) {
        ElementWithValueBase.getValueInfos = Symbol('ElementGeneric_getValueInfos');
    })(ElementWithValueBase = privates.ElementWithValueBase || (privates.ElementWithValueBase = {}));
})(privates || (privates = {}));
export class tswStyleRule {
    constructor(propName, propValue) {
        this.propName = propName;
        this.propValue = propValue;
    }
}
export class tswElement {
    constructor(tagName, ns) {
        this._tagName = tagName;
        this._ns = ns;
    }
    attr(name, val) {
        this.addAttr(name, val);
        return this;
    }
    id(val) {
        this.addAttr('id', val);
        return this;
    }
    cls(val) {
        this.addAttr('class', val);
        return this;
    }
    style(val) {
        this.addAttr('style', val);
        return this;
    }
    styleRule(name, val) {
        if (name != null) {
            const sr = new tswStyleRule(name, val);
            this.addAttr('style', sr);
        }
        return this;
    }
    data(name, val) {
        this.attr('data-' + name.toLowerCase(), val);
        return this;
    }
    disabled(val) {
        this.attr('disabled', val);
        return this;
    }
    hidden(val) {
        this.attr('hidden', val);
        return this;
    }
    children(items) {
        if (items != null) {
            this._children = this._children || [];
            this._children.push(items);
        }
        return this;
    }
    onClick(handler) {
        return this.onEvent('click', handler);
    }
    onEvent(eventName, handler) {
        if (eventName && handler instanceof Function) {
            this[privates.ElementGeneric.addHandler]({ eventName, handleEvent: handler, eventType: 'dom', eventKind: EventKind.onRoot });
        }
        return this;
    }
    onEventDirect(eventName, handler) {
        if (eventName && handler instanceof Function) {
            this[privates.ElementGeneric.addHandler]({ eventName, handleEvent: handler, eventType: 'dom', eventKind: EventKind.direct });
        }
        return this;
    }
    [privates.ElementGeneric.addHandler](item) {
        if (this._eventHandlers == null)
            this._eventHandlers = [];
        this._eventHandlers.push(item);
    }
    addRef(ref) {
        if (ref != null) {
            this._refs = this._refs || [];
            this._refs.push(ref);
        }
        return this;
    }
    addAttr(name, val) {
        if (!this._tagName)
            throw new Error("Can not set attributes on document fragment");
        this._attrs = this._attrs || [];
        this._attrs.push({ attrName: name, attrValue: val });
    }
    [privates.ElementGeneric.tagName]() { return this._tagName; }
    [privates.ElementGeneric.ns]() { return this._ns; }
    [privates.ElementGeneric.children]() { return this._children; }
    [privates.ElementGeneric.attrs]() { return this._attrs; }
    [privates.ElementGeneric.events]() { return this._eventHandlers; }
    [privates.ElementGeneric.getRefs]() { return this._refs; }
}

==> tswlib-1.4.0.tgz: package/elm.js <==
import { EventKind } from "./types";
export var privates;
(function (privates) {
    let ElementGeneric;
    (function (ElementGeneric) {
        ElementGeneric.tagName = Symbol('ElementGeneric_tagName');
        ElementGeneric.ns = Symbol('ElementGeneric_ns');
        ElementGeneric.children = Symbol('ElementGeneric_children');
        ElementGeneric.addHandler = Symbol('ElementGeneric_addHandler');
        ElementGeneric.attrs = Symbol('ElementGeneric_attrs');
        ElementGeneric.attrsCaseSensitive = Symbol('ElementGeneric_attrsCaseSensitive');
        ElementGeneric.events = Symbol('ElementGeneric_events');
        ElementGeneric.getRefs = Symbol('ElementGeneric_getRefs');
    })(ElementGeneric = privates.ElementGeneric || (privates.ElementGeneric = {}));
    let ElementWithValueBase;
    (function (ElementWithValueBase) {
        ElementWithValueBase.getValueInfos = Symbol('ElementGeneric_getValueInfos');
    })(ElementWithValueBase = privates.ElementWithValueBase || (privates.ElementWithValueBase = {}));
})(privates || (privates = {}));
export class tswStyleRule {
    propName;
    propValue;
    constructor(propName, propValue) {
        this.propName = propName;
        this.propValue = propValue;
    }
}
export class tswElement {
    _tagName;
    _ns;
    _attrs;
    _attrsCaseSensitive;
    _children;
    _eventHandlers;
    _refs;
    constructor(tagName, ns, _attrsCaseSensitive = false) {
        this._tagName = tagName;
        this._ns = ns;
        this._attrsCaseSensitive = _attrsCaseSensitive;
    }
    attr(name, val) {
        this.addAttr(name, val);
        return this;
    }
    id(val) {
        this.addAttr('id', val);
        return this;
    }
    cls(val) {
        this.addAttr('class', val);
        return this;
    }
    style(val) {
        this.addAttr('style', val);
        return this;
    }
    styleRule(name, val) {
        if (name != null) {
            const sr = new tswStyleRule(name, val);
            this.addAttr('style', sr);
        }
        return this;
    }
    data(name, val) {
        this.attr('data-' + name.toLowerCase(), val);
        return this;
    }
    disabled(val) {
        this.attr('disabled', val);
        return this;
    }
    hidden(val) {
        this.attr('hidden', val);
        return this;
    }
    children(items) {
        if (items != null) {
            this._children = this._children ?? [];
            this._children.push(items);
        }
        return this;
    }
    onClick(handler) {
        return this.onEvent('click', handler);
    }
    onEvent(eventName, handler) {
        if (eventName && handler instanceof Function) {
            this[privates.ElementGeneric.addHandler]({ eventName, handleEvent: handler, eventType: 'dom', eventKind: EventKind.onRoot });
        }
        return this;
    }
    onEventDirect(eventName, handler) {
        if (eventName && handler instanceof Function) {
            this[privates.ElementGeneric.addHandler]({ eventName, handleEvent: handler, eventType: 'dom', eventKind: EventKind.direct });
        }
        return this;
    }
    [privates.ElementGeneric.addHandler](item) {
        if (this._eventHandlers == null)
            this._eventHandlers = [];
        this._eventHandlers.push(item);
    }
    addRef(ref) {
        if (ref != null) {
            const el = ref.get();
            if (el != null)
                throw new Error('ref is already attached');
            this._refs = this._refs ?? [];
            this._refs.push(ref);
        }
        return this;
    }
    addAttr(name, val) {
        if (!this._tagName)
            throw new Error("Can not set attributes on document fragment");
        this._attrs = this._attrs ?? [];
        this._attrs.push({ attrName: name, attrValue: val });
    }
    [privates.ElementGeneric.tagName]() { return this._tagName; }
    [privates.ElementGeneric.ns]() { return this._ns; }
    [privates.ElementGeneric.children]() { return this._children; }
    [privates.ElementGeneric.attrs]() { return this._attrs; }
    [privates.ElementGeneric.attrsCaseSensitive]() { return this._attrsCaseSensitive; }
    [privates.ElementGeneric.events]() { return this._eventHandlers; }
    [privates.ElementGeneric.getRefs]() { return this._refs; }
}
